import { DeclarationOptions } from './module.declarator';
import { PathSolver } from './path.solver';
/**
 * The `ModuleImportDeclarator` class is responsible for declaring module imports
 * in a TypeScript file. It provides methods to insert import statements into the
 * file content based on the provided declaration options.
 */
export declare class ModuleImportDeclarator {
    private solver;
    constructor(solver?: PathSolver);
    /**
     * Declares a module import in the given content string.
     *
     * @param content - The content of the file where the import will be declared.
     * @param options - The options for the declaration, including the symbol and path.
     * @returns The updated content string with the import statement inserted.
     */
    declare(content: string, options: DeclarationOptions): string;
    /**
     * Finds the endpoint of the existing import statements in the content.
     *
     * @param contentLines - The lines of the content.
     * @returns The index of the last import statement.
     */
    private findImportsEndpoint;
    /**
     * Builds the import line to insert based on the declaration options.
     *
     * @param options - The options for the declaration, including the symbol and path.
     * @returns The import line to insert.
     */
    private buildLineToInsert;
    /**
     * Computes the relative path for the import statement.
     *
     * @param options - The options for the declaration, including the symbol and path.
     * @returns The relative path for the import statement.
     */
    private computeRelativePath;
}
