"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModuleMetadataDeclarator = void 0;
const metadata_manager_1 = require("./metadata.manager");
/**
 * The `ModuleMetadataDeclarator` class is responsible for declaring metadata
 * in a TypeScript file. It provides methods to insert metadata entries into the
 * file content based on the provided declaration options.
 */
class ModuleMetadataDeclarator {
    /**
     * Declares metadata in the given content string.
     *
     * @param content - The content of the file where the metadata will be declared.
     * @param options - The options for the declaration, including the metadata, symbol, and static options.
     * @returns The updated content string with the metadata entry inserted.
     */
    declare(content, options) {
        const manager = new metadata_manager_1.MetadataManager(content);
        const inserted = manager.insert(options.metadata, options.symbol, options.staticOptions);
        return inserted !== null && inserted !== void 0 ? inserted : content;
    }
}
exports.ModuleMetadataDeclarator = ModuleMetadataDeclarator;
