import { Path } from '@angular-devkit/core';
import { ModuleImportDeclarator } from './module-import.declarator';
import { ModuleMetadataDeclarator } from './module-metadata.declarator';
export interface DeclarationOptions {
    metadata: string;
    type?: string;
    name: string;
    className?: string;
    path: Path;
    module: Path;
    symbol?: string;
    staticOptions?: {
        name: string;
        value: Record<string, never>;
    };
}
export declare class ModuleDeclarator {
    private imports;
    private metadata;
    /**
     * Constructs a new `ModuleDeclarator` instance.
     *
     * @param imports - The `ModuleImportDeclarator` instance for handling import declarations.
     * @param metadata - The `ModuleMetadataDeclarator` instance for handling metadata declarations.
     */
    constructor(imports?: ModuleImportDeclarator, metadata?: ModuleMetadataDeclarator);
    /**
     * Declares module imports and metadata in the given content string.
     *
     * @param content - The content of the file where the declarations will be made.
     * @param options - The options for the declaration, including the symbol and static options.
     * @returns The updated content string with the declarations inserted.
     */
    declare(content: string, options: DeclarationOptions): string;
    /**
     * Computes the symbol for the declaration options if not provided.
     *
     * @param options - The options for the declaration.
     * @returns The updated declaration options with the computed symbol.
     */
    private computeSymbol;
}
