"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModuleDeclarator = void 0;
const strings_1 = require("@angular-devkit/core/src/utils/strings");
const module_import_declarator_1 = require("./module-import.declarator");
const module_metadata_declarator_1 = require("./module-metadata.declarator");
class ModuleDeclarator {
    /**
     * Constructs a new `ModuleDeclarator` instance.
     *
     * @param imports - The `ModuleImportDeclarator` instance for handling import declarations.
     * @param metadata - The `ModuleMetadataDeclarator` instance for handling metadata declarations.
     */
    constructor(imports = new module_import_declarator_1.ModuleImportDeclarator(), metadata = new module_metadata_declarator_1.ModuleMetadataDeclarator()) {
        this.imports = imports;
        this.metadata = metadata;
    }
    /**
     * Declares module imports and metadata in the given content string.
     *
     * @param content - The content of the file where the declarations will be made.
     * @param options - The options for the declaration, including the symbol and static options.
     * @returns The updated content string with the declarations inserted.
     */
    declare(content, options) {
        options = this.computeSymbol(options);
        content = this.imports.declare(content, options);
        content = this.metadata.declare(content, options);
        return content;
    }
    /**
     * Computes the symbol for the declaration options if not provided.
     *
     * @param options - The options for the declaration.
     * @returns The updated declaration options with the computed symbol.
     */
    computeSymbol(options) {
        const target = Object.assign({}, options);
        if (options.className) {
            target.symbol = options.className;
        }
        else if (options.type !== undefined) {
            target.symbol = (0, strings_1.classify)(options.name).concat((0, strings_1.capitalize)(options.type));
        }
        else {
            target.symbol = (0, strings_1.classify)(options.name);
        }
        return target;
    }
}
exports.ModuleDeclarator = ModuleDeclarator;
