"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModuleFinder = void 0;
const core_1 = require("@angular-devkit/core");
class ModuleFinder {
    constructor(tree) {
        this.tree = tree;
    }
    /**
     * Finds the module file in the given path.
     *
     * @param options - The options for finding the module, including the path.
     * @returns The path to the module file, or null if not found.
     */
    find(options) {
        const generatedDirectoryPath = options.path;
        const generatedDirectory = this.tree.getDir(generatedDirectoryPath);
        return this.findIn(generatedDirectory);
    }
    /**
     * Recursively searches for the module file in the given directory.
     *
     * @param directory - The directory to search in.
     * @returns The path to the module file, or null if not found.
     */
    findIn(directory) {
        if (!directory) {
            return null;
        }
        const moduleFilename = directory.subfiles.find((filename) => /\.module\.(t|j)s$/.test(filename));
        return moduleFilename !== undefined
            ? (0, core_1.join)(directory.path, moduleFilename.valueOf())
            : this.findIn(directory.parent);
    }
}
exports.ModuleFinder = ModuleFinder;
