"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeSourceRoot = exports.isInRootDirectory = void 0;
const core_1 = require("@angular-devkit/core");
const defaults_1 = require("../lib/defaults");
/**
 * Checks if the current directory is the root directory.
 *
 * @param host - The file tree representing the project.
 * @param extraFiles - Additional files to check for in the root directory.
 * @returns True if the current directory is the root directory, otherwise false.
 */
function isInRootDirectory(host, extraFiles = []) {
    const files = [].concat(extraFiles || []);
    return files.map((file) => host.exists(file)).some((isPresent) => isPresent);
}
exports.isInRootDirectory = isInRootDirectory;
/**
 * Merges the source root with the provided options.
 * @param options - The options to merge with the source root.
 * @returns A rule to merge the source root with the provided options.
 */
function mergeSourceRoot(options) {
    return (host) => {
        const isInRoot = isInRootDirectory(host, ['tsconfig.json', 'package.json']);
        if (!isInRoot) {
            return host;
        }
        const defaultSourceRoot = options.sourceRoot !== undefined ? options.sourceRoot : defaults_1.DEFAULT_PATH_NAME;
        options.path =
            options.path !== undefined
                ? (0, core_1.join)((0, core_1.normalize)(defaultSourceRoot), options.path)
                : (0, core_1.normalize)(defaultSourceRoot);
        return host;
    };
}
exports.mergeSourceRoot = mergeSourceRoot;
